@@ -39,12 +39,6 @@
 #   include "modeltest.h"
 #endif
 
-#ifdef Q_WS_MAC
-#   define ICON_PREFIX ":/icons/mac/"
-#else
-#   define ICON_PREFIX ":/icons/"
-#endif
-
 const int PROGRESS_HEIGHT = 17;
 static const char *DORIAN_VERSION =
 #include "pkg/version.txt"
@@ -116,8 +110,25 @@ MainWindow::MainWindow(QWidget *parent):
     connect(Library::instance(), SIGNAL(nowReadingChanged()),
             this, SLOT(onCurrentBookChanged()));
 
-    // Load book on command line, or load last read book, or load default book
+    // Load library, upgrade it if needed
+    libraryProgress = new QProgressDialog(tr("Upgrading library"), "", 0, 0, this);
+    libraryProgress->reset();
+    libraryProgress->setMinimumDuration(0);
+    libraryProgress->setWindowModality(Qt::WindowModal);
+    libraryProgress->setCancelButton(0);
     Library *library = Library::instance();
+    connect(library, SIGNAL(beginUpgrade(int)), this, SLOT(onBeginUpgrade(int)));
+    connect(library, SIGNAL(upgrading(const QString &)),
+            this, SLOT(onUpgrading(const QString &)));
+    connect(library, SIGNAL(endUpgrade()), this, SLOT(onEndUpgrade()));
+    connect(library, SIGNAL(beginLoad(int)), this, SLOT(onBeginLoad(int)));
+    connect(library, SIGNAL(loading(const QString &)),
+            this, SLOT(onLoading(const QString &)));
+    connect(library, SIGNAL(endLoad()), this, SLOT(onEndLoad()));
+    library->upgrade();
+    library->load();
+
+    // Load book on command line, or load last read book, or load default book
     if (QCoreApplication::arguments().size() == 2) {
         QString path = QCoreApplication::arguments()[1];
         library->add(path);
@@ -125,13 +136,11 @@ MainWindow::MainWindow(QWidget *parent):
         if (index.isValid()) {
             library->setNowReading(index);
         }
-    }
-    else {
+    } else {
         QModelIndex index = library->nowReading();
         if (index.isValid()) {
             library->setNowReading(index);
-        }
-        else {
+        } else {
             if (!library->rowCount()) {
                 library->add(":/books/2BR02B.epub");
             }
@@ -297,8 +306,7 @@ void MainWindow::onSettingsChanged(const QString &key)
         if (value == "portrait") {
             setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
             setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-        }
-        else {
+        } else {
             setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
             setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
         }
@@ -456,3 +464,45 @@ void MainWindow::goToPreviousPage()
     previousButton->flash(1500);
     view->goPreviousPage();
 }
+
+void MainWindow::onBeginUpgrade(int total)
+{
+    libraryProgress->setVisible(total > 0);
+    libraryProgress->setWindowTitle(tr("Upgrading library"));
+    libraryProgress->setMaximum(total);
+}
+
+void MainWindow::onUpgrading(const QString &path)
+{
+    libraryProgress->setLabelText(tr("Upgrading %1").
+                                  arg(QFileInfo(path).fileName()));
+    libraryProgress->setValue(libraryProgress->value() + 1);
+}
+
+void MainWindow::onEndUpgrade()
+{
+    libraryProgress->hide();
+    libraryProgress->reset();
+}
+
+
+void MainWindow::onBeginLoad(int total)
+{
+    libraryProgress->setVisible(total > 0);
+    libraryProgress->setWindowTitle(tr("Loading library"));
+    libraryProgress->setMaximum(total);
+}
+
+void MainWindow::onLoading(const QString &path)
+{
+    libraryProgress->setLabelText(tr("Loading %1").
+                                  arg(QFileInfo(path).fileName()));
+    libraryProgress->setValue(libraryProgress->value() + 1);
+}
+
+void MainWindow::onEndLoad()
+{
+    libraryProgress->hide();
+    libraryProgress->reset();
+}
+
