@@ -41,6 +41,12 @@ public slots:
     void about();
     void goToNextPage();
     void goToPreviousPage();
+    void onBeginUpgrade(int total);
+    void onUpgrading(const QString &book);
+    void onEndUpgrade();
+    void onBeginLoad(int total);
+    void onLoading(const QString &book);
+    void onEndLoad();
 
 protected:
     void closeEvent(QCloseEvent *event);
@@ -67,6 +73,7 @@ private:
     Progress *progress;
     TranslucentButton *previousButton;
     TranslucentButton *nextButton;
+    QProgressDialog *libraryProgress;
 };
 
 #endif // MAINWINDOW_H
